==> aws_cdk.aws_iot_alpha-2.34.0a0-py3-none-any.whl: package/.warnings.jsii.js <==
function _aws_cdk_aws_iot_alpha_IAction(p) {
}
function _aws_cdk_aws_iot_alpha_ActionConfig(p) {
}
function _aws_cdk_aws_iot_alpha_IotSqlConfig(p) {
}
function _aws_cdk_aws_iot_alpha_IotSql(p) {
}
function _aws_cdk_aws_iot_alpha_ITopicRule(p) {
}
function _aws_cdk_aws_iot_alpha_TopicRuleProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.sql))
            _aws_cdk_aws_iot_alpha_IotSql(p.sql);
        if (!visitedObjects.has(p.actions))
            _aws_cdk_aws_iot_alpha_IAction(p.actions);
        if (!visitedObjects.has(p.errorAction))
            _aws_cdk_aws_iot_alpha_IAction(p.errorAction);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_iot_alpha_TopicRule(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_iot_alpha_IAction, _aws_cdk_aws_iot_alpha_ActionConfig, _aws_cdk_aws_iot_alpha_IotSqlConfig, _aws_cdk_aws_iot_alpha_IotSql, _aws_cdk_aws_iot_alpha_ITopicRule, _aws_cdk_aws_iot_alpha_TopicRuleProps, _aws_cdk_aws_iot_alpha_TopicRule };

==> aws_cdk.aws_iot_alpha-2.149.0a0-py3-none-any.whl: package/.warnings.jsii.js <==
function _aws_cdk_aws_iot_alpha_IAction(p) {
}
function _aws_cdk_aws_iot_alpha_ActionConfig(p) {
}
function _aws_cdk_aws_iot_alpha_IotSqlConfig(p) {
}
function _aws_cdk_aws_iot_alpha_IotSql(p) {
}
function _aws_cdk_aws_iot_alpha_ITopicRule(p) {
}
function _aws_cdk_aws_iot_alpha_TopicRuleProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.sql))
            _aws_cdk_aws_iot_alpha_IotSql(p.sql);
        if (p.actions != null)
            for (const o of p.actions)
                if (!visitedObjects.has(o))
                    _aws_cdk_aws_iot_alpha_IAction(o);
        if (!visitedObjects.has(p.errorAction))
            _aws_cdk_aws_iot_alpha_IAction(p.errorAction);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_iot_alpha_TopicRule(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_iot_alpha_IAction, _aws_cdk_aws_iot_alpha_ActionConfig, _aws_cdk_aws_iot_alpha_IotSqlConfig, _aws_cdk_aws_iot_alpha_IotSql, _aws_cdk_aws_iot_alpha_ITopicRule, _aws_cdk_aws_iot_alpha_TopicRuleProps, _aws_cdk_aws_iot_alpha_TopicRule };
